ITP_proj: testing the number of row factors- with projection
Description
This function tests whether the number of row factors is equal or larger
than a given integer, under a two-way factor model, using projected version
of sample covariance.
Usage
ITP_proj(
Y,
k = 1,
alpha = 0.05,
kmax = 4,
epsilon = 0.05,
r = 8,
M = 100,
S = 100,
fq = 1/4
)
Value
a logical value. 1 for "the number of row factors is smaller than k".
0 for "at least k row factors exists".
Arguments
Y
data, a \(T\times p1\times p2\) array.
k
an positive integer indicating which eigenvalue to test.
alpha
a number in (0,1), indicating the significance of the test.
kmax
a positive integer smaller than p2, indicating the
upper bound for the factor numbers, and the dimension of projection matrix.
epsilon
a small positive number in (0,1), indicating the size of scaling.
r
a positive number indicating the order of the power function
for transforming the rescaled eigenvalue.
M
a large integer for the number of Gaussian variables in the randomized test.
S
another large integer for the number of replications in the strong rule. Usually \(M=S=T\).
fq
a number in (0,0.5), controlling the threshold function of the strong rule.
Details
See He et al. (2023)
References
He Y, Kong X, Trapani L, & Yu L (2023).
One-way or two-way factor model for matrix sequences? Journal of Econometrics,
235(2), 1981-2004.