This function tests the existence of k-th moment by randomized method in
Trapani (2016).
Usage
moment.test(x, k = 16, R = 400)
Value
a scalar in \([0,1]\), indicating the p-value
of the test. The null hypothese is that the k-th moment doesn't exist.
Therefore, a small p-value indicates the existense of the k-th moment.
Arguments
x
a numeric vector of data samples.
k
a number no smaller than 4, indicating that the procedure will test
the existence of the k-th moment when k is even. Otherwise, the procedure
will test the existence of the \(k'\)-th moment, with
\(k'=round(k/2,0)\times 2\).
R
the number of standard Gaussian variables generated in the
randomized test; see more details in Trapani (2016).
Author
Yong He, Xinbing Kong, Lorenzo Trapani, Long Yu
Details
The procedure is adapted from Trapani (2016) with \(\psi=2\), where
\(\psi\) is a tuning parameter to scale the sample moments defined
in Section 3.1 of Trapani (2016). For simplicity, we only test the 4th, 6th,
... 2c-th moments.
References
Trapani, L. (2016). Testing for (in) finite moments.
Journal of Econometrics, 191(1), 57-68.